# scotch-tape

Helps write better tape tests and better organize your test code. 

##code

```
var scotchTape = require('scotch-tape');
var test = scotchTape({options});
```

####Supported Options:

* `setup` - called before any tests starts running.
* `before` - called before every test run
* `after` - called after every test run
* `teardown` - called after all the tests are run

## scotch-tape flavor

#### Initialization
```
'use strict';

var scotchTape = require('scotch-tape');

var test = scotchTape({
  setup: function initialize(t) {
    console.log('setup');
    t.end();
  },
  before: function beforeEach(t) {
    console.log('Before Each');
    t.end();
  },
  after: function afterEach(t) {
    console.log('After Each');
    t.end();
  },
  teardown: function cleanup(t) {
    console.log('teardown');
    t.end();
  }
});
```
#### Sample Tests
```
test('Project Tests', function test(it) {
  it('should pass 1', function should(t) {
    t.ok(true);
    t.end();
  });
  it('should pass 2', function should(t) {
    t.ok(true);
    t.end();
  });
});
```
#### Console Output
```
TAP version 13
# setup
setup
# Project Tests > should pass 1
Before Each
ok 1 (unnamed assert)
After Each
# Project Tests > should pass 2
Before Each
ok 2 (unnamed assert)
After Each
# teardown
teardown

1..2
# tests 2
# pass  2

# ok
```

## vanilla flavor

As the provided hooks are optional, not using them would mean you can fallback to vanilla tape js tests.

```
'use strict';

var scotchTape = require('scotch-tape');

var test = scotchTape();
test('Project Tests', function test(it) {
  it('should pass 1', function should(t) {
    t.ok(true);
    t.end();
  });
  it('should pass 2', function should(t) {
    t.ok(true);
    t.end();
  });
});

```

#### Console Output
```
TAP version 13
# Basic Tests > should pass 1
ok 1 called
# Basic Tests > should pass 2
ok 2 called

1..2
# tests 2
# pass  2

# ok
```


> ENJOY WRITING BETTER TESTS